@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """ Unit tests for 'zuite' module.
 
 $Id$
@@ -17,23 +18,78 @@ class DummyResponse:
     def write( self, body ):
         self._body = body
 
+CONTENT_suite_html = """
+ <table border="1" cellpadding="1" cellspacing="1">
+
+ <tbody>
+
+  <tr class="title                                      status_failed">
+   <td>
+    <b>Test Suite: portal_tests</b>
+   </td>
+  </tr>
+
+  <tr class="  status_failed">
+   <td>
+    <a href="portal_zuite/testSomething">testSomething</a>
+   </td>
+  </tr>
+
+ </tbody></table>
+""".strip()
+
+CONTENT_testTable_1 = """
+<div>
+<table border="1" cellpadding="1" cellspacing="1">
+<thead>
+<tr class="title status_failed"><td rowspan="1" colspan="3">Test Something</td></tr>
+
+<tr class="  status_done" style="cursor: pointer;">
+  <td>type</td>
+  <td>field_my_bar_category_title_list</td>
+  <td>azértï</td>
+</tr>
+
+</thead><tbody>
+""".strip()
+
 class ZuiteTests( unittest.TestCase ):
 
     _OLD_NOW = _MARKER = object()
 
     def setUp( self ):
         import transaction
+        from zope.component.testing import setUp as componentSetUp
+        from zope.component import provideUtility
+        from zope.component import provideAdapter
+        from zope.traversing.adapters import DefaultTraversable
+        from zope.publisher.http import HTTPCharsets
         from Testing.ZopeTestCase import ZopeLite
         from Testing.makerequest import makerequest
+        from Products.PageTemplates.interfaces \
+            import IUnicodeEncodingConflictResolver
+        from Products.PageTemplates.unicodeconflictresolver \
+            import PreferredCharsetResolver
+
+
+        componentSetUp()
+        provideAdapter(DefaultTraversable, (None,))
+        provideUtility(PreferredCharsetResolver,
+                       IUnicodeEncodingConflictResolver)
+        provideAdapter(HTTPCharsets)
         transaction.begin()
         app = ZopeLite.app()
         self.root = makerequest(app)
+        # set the request charset to enable conversions to utf-8
+        self.root.REQUEST['HTTP_ACCEPT_CHARSET'] = '*'
 
     def tearDown( self ):
         import transaction
+        from zope.component.testing import tearDown as componentTearDown
         if self._OLD_NOW is not self._MARKER:
             self._setNow( self._OLD_NOW )
         transaction.abort()
+        componentTearDown()
 
     def _getTargetClass( self ):
 
@@ -625,6 +681,47 @@ class ZuiteTests( unittest.TestCase ):
 
         self._verifyArchive( archive.data, expected )
 
+    def test_unicode_zuite_result(self):
+        from DateTime.DateTime import DateTime
+        from Products.Zelenium.zuite import ZuiteResults
+        from OFS.Image import File
+
+        zuite = self._makeOne().__of__( self.root )
+        # simulating zuite.postResults to create ZuiteResults object
+        completed = DateTime('2010-05-30')
+        result_id = 'result_%s' % completed.strftime( '%Y%m%d_%H%M%S' )
+        zresults = ZuiteResults(result_id).__of__(zuite)
+        zresults.manage_changeProperties(completed=completed,
+                                         passed=False,
+                                         time_secs=0,
+                                         tests_passed=0,
+                                         tests_failed=0,
+                                         commands_passed=0,
+                                         commands_failed=0,
+                                         commands_with_errors=0,
+                                         user_agent='unknown',
+                                         remote_addr='unknown',
+                                         http_host='unknown',
+                                         server_software='unknown',
+                                         product_info=zuite._listProductInfo())
+        zresults._setObject( 'suite.html'
+                           , File( 'suite.html'
+                                 , 'Test Suite'
+                                 , CONTENT_suite_html
+                                 , 'text/html'
+                                 )
+                           )
+
+        zresults._setObject( 'testTable.1'
+                           , File( 'testTable.1'
+                                 , 'Test case: testTable.1'
+                                 , CONTENT_testTable_1
+                                 , 'text/html'
+                                 )
+                           )
+        self.failUnless( u'azértï' in zresults.index_html() )
+
+
 def test_suite():
     return unittest.TestSuite((
         unittest.makeSuite( ZuiteTests ),
